
FOREST = 1
BURNING = 2
BURNED = 3
EMPTY = 4

world = CellularSpace{
	xdim = 50,
	ydim = 50
}

world:createNeighborhood{
	strategy = "vonneumann",
	self = false
}

forEachCell(world, function(cell)
	if math.random() > 0.1 then
		cell.cover = FOREST
	else
		cell.cover = EMPTY
	end
end)


legend = Legend {
	grouping = "uniquevalue",
	colorBar = {
		{value = FOREST, color = "green"},
		{value = BURNING, color = "red"},
		{value = BURNED, color = "brown"},
		{value = EMPTY, color = "white"}
	}
}

Observer{
	subject = world,
	attributes = {"cover"},
	legends = {legend}
}

update = function(cs)
	forEachCell(cs, function(cell)
		if cell.past.cover == FOREST then
			forEachNeighbor(cell, function(cell, neighbor)
				if neighbor.past.cover == BURNING then
					cell.cover = BURNING
				end
			end)
		elseif cell.past.cover == BURNING then
			cell.cover = BURNED
		end
	end)
end

world:sample().cover = BURNING
world:notify()

t = Timer{
	Event{action = function(e)
		world:synchronize()
		update(world)
		world:notify()
	end}
}

t:execute(100)

